@@ -40,86 +40,94 @@ def parse_arguments():
 def daily_avg(station: str , medfilter: float, ReqTracks: int, txtfile: str = None, plt: bool = True, 
         extension: str = '', year1: int = 2005, year2: int = 2030, fr: int = 0, csv: bool = False, azim1: int = 0, azim2: int = 360, test: bool = False, subdir: str=None):
     """
-        Parameters
-        ----------
-        station : string
-            4 ch station name 
+    The goal is to consolidate individual RH results into a single file consisting of daily averaged RH without outliers.
 
-        medfilter : float
-            Median filter for daily reflector height (m). Start with 0.25 for surfaces where you expect no significant 
-            subdaily change (snow/lakes).
+    Currently called as : daily_avg p041 0.25 10 
 
-        ReqTracks : int
-            Required number of daily satellite tracks to save the daily average value.
+    where p041 is the station name, 0.25 is the median filter value in meters, and 10 is the number of values required to
+    trust the daily average.
 
-        txtfile : str, optional
-            Use this parameter to set your own output filename.
-            default is to let the code choose.
+    There are multiple optional choices as discussed below. The code also creates a file with all the subdaily RH as well.
 
-        plt : bool, optional
-            whether to print plots to screen or not.
-            default is True.
+    Parameters
+    ----------
+    station : string
+        4 ch station name 
 
-        extension : str, optional
-            extension for solution names.
-            default is ''. (empty string)
+    medfilter : float
+        Median filter for daily reflector height (m). Start with 0.25 for surfaces where you expect no significant 
+        subdaily change (snow/lakes).
 
-        year1 : int, optional
-            restrict to years starting with.
-            default is 2005.
+    ReqTracks : int
+        Required number of daily satellite tracks to save the daily average value.
 
-        year2 : int, optional
-            restrict to years ending with.
-            default is 2030.
+    txtfile : str, optional
+        Use this parameter to set your own output filename.
+        default is to let the code choose.
 
-        fr : int, optional
-            GNSS frequency. Value options:
-                0 (default) : all
+    plt : bool, optional
+        whether to print plots to screen or not.
+        default is True.
 
-                1 : GPS L1
+    extension : str, optional
+        extension for solution names.
+        default is ''. (empty string)
 
-                2 : GPS L2
+    year1 : int, optional
+        restrict to years starting with.
+        default is 2005.
 
-                20 : GPS L2C
+    year2 : int, optional
+        restrict to years ending with.
+        default is 2030.
 
-                5 : GPS L5
+    fr : int, optional
+        GNSS frequency. If none input, all are used. Value options:
 
-                101 : GLONASS L1
+            1 : GPS L1
 
-                102 : GLONASS L2
+            2 : GPS L2
 
-                201 : GALILEO E1
+            20 : GPS L2C
 
-                205 : GALILEO E5a
+            5 : GPS L5
 
-                206 : GALILEO E6
+            101 : GLONASS L1
 
-                207 : GALILEO E5b
+            102 : GLONASS L2
 
-                208 : GALILEO E5
+            201 : GALILEO E1
 
-                302 : BEIDOU B1
+            205 : GALILEO E5a
 
-                306 : BEIDOU B3
+            206 : GALILEO E6
 
-                307 : BEIDOU B2
+            207 : GALILEO E5b
 
-        csv : boolean, optional
-            Whether you want csv instead of a plain text file.
-            default is False.
+            208 : GALILEO E5
 
-        azim1 : int, optional
-            minimum azimuth, degrees
-            note: should be modified to allow negative azimuth
+            302 : BEIDOU B1
 
-        azim2 : int, optional
-            maximum azimuth, degrees
+            306 : BEIDOU B3
 
-        test : bool
-            augmentations to the plot
+            307 : BEIDOU B2
 
-        subdir: str
-            non-default subdirectory for Files output
+    csv : boolean, optional
+        Whether you want csv instead of a plain text file.
+        default is False.
+
+    azim1 : int, optional
+        minimum azimuth, degrees
+        note: should be modified to allow negative azimuth
+
+    azim2 : int, optional
+        maximum azimuth, degrees
+
+    test : bool
+        augmentations to the plot
+
+    subdir: str
+        non-default subdirectory for Files output
 
     """
     if len(station) != 4:
