@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import argparse
 import datetime
-import matplotlib.pyplot as plt
 import os
 import requests
 import subprocess
@@ -10,6 +9,135 @@ import gnssrefl.gps as g
 
 from gnssrefl.utils import validate_input_datatypes, str2bool
 
+def parse_arguments():
+    parser = argparse.ArgumentParser()
+    parser.add_argument("station", help="station name, e.g. 8768094", type=str)
+    parser.add_argument("date1", help="start-date, 20150101", type=str)
+    parser.add_argument("date2", help="end-date, 20150110", type=str)
+    parser.add_argument("-output", default=None, help="Optional output filename", type=str)
+    parser.add_argument("-plt", default=None, help="quick plot to screen", type=str)
+    parser.add_argument("-datum", default=None, help="datum (lwd for lakes?)", type=str)
+    parser.add_argument("-subdir", default=None, help="optional subdirectory name for output", type=str)
+    args = parser.parse_args().__dict__
+
+    # convert all expected boolean inputs from strings to booleans
+    boolean_args = ['plt']
+    args = str2bool(args, boolean_args)
+
+
+    # only return a dictionary of arguments that were added from the user - all other defaults will be set in code below
+    return {key: value for key, value in args.items() if value is not None}
+
+def download_tides(station: str, date1: str, date2: str, output: str = None, plt: bool = False, datum: str = 'mllw', subdir: str = None):
+    """
+    Downloads NOAA tide gauge files and stores locally
+    If you ask for 31 days of data or less, it will download exactly what you ask for.
+    But if you want a longer time series, this code needs to query the NOAA API every month.
+    To make the code easier to write, I start with the first day of the first month you ask for and end with
+    last day in the last month.
+
+    Output is written to REFL_CODE/Files/ unless subdir optional input is set
+    Plot is sent to the screen if requested.
+
+    Parameters 
+    ----------
+    station : str
+        7 character ID of the station.
+
+    date1 : str
+        start date.
+        Example value: 20150101
+
+    date2 : str
+        end date.
+        Example value: 20150110
+
+    output : string, optional
+        Optional output filename
+        default is None
+
+    plt: boolean, optional
+        plot comes to the screen
+        default is None
+
+    datum: string, optional
+        set to lwd for lakes?
+        default is mllw
+
+    subdir : str, optional
+        subdirectory for output in the $REFL_CODE/Files area
+
+    """
+    g.check_environ_variables()
+
+    xdir = os.environ['REFL_CODE']
+    outdir = xdir  + '/Files/'
+    if not os.path.exists(outdir) :
+        subprocess.call(['mkdir', outdir])
+
+    if (subdir is None):
+        print('Using regular output directory',outdir )
+    else:
+        outdir = xdir  + '/Files/' + subdir + '/'
+        print('User requested a subdirectory for output', outdir)
+        if not os.path.exists(outdir):
+            subprocess.call(['mkdir', outdir])
+
+    if len(station) != 7:
+        print('station must have 7 characters ', station); sys.exit()
+    if len(date1) != 8:
+        print('date1 must have 8 characters', date1); sys.exit()
+    if len(date2) != 8:
+        print('date2 must have 8 characters', date2); sys.exit()
+
+
+    csv = False
+    # use the default, which is plain text
+    if output is None:
+        outfile = outdir + station + '_' + 'noaa.txt'
+    else:
+        if output[-3:] == 'csv':
+            csv = True
+        outfile = outdir + output
+
+    print('Writing contents to: ', outfile)
+    fout = open(outfile, 'w+')
+    if csv:
+        fout.write("{0:s} {1:s} \n".format('#', 'NOAA Station: ' + station ))
+        fout.write("#YYYY,MM,DD,HH,MM, SS, Water(m),DOY,   MJD \n")
+        #fout.write("#YYYY,MM,DD,HH,MM, Water(m),DOY,   MJD, Seconds\n")
+    else:
+        #fout.write("%YYYY MM DD HH MM  Water(m) DOY    MJD      Seconds\n")
+        #fout.write("% 1    2  3  4  5    6       7       8         9\n")
+        fout.write("{0:s} \n".format('%' + ' NOAA Station: ' + station ))
+        fout.write("%YYYY MM DD HH MM  SS Water(m) DOY    MJD  \n")
+        fout.write("% 1    2  3  4  5   6   7       8     9\n")
+
+
+    year1, month1, day1, doy1,modjul1 = noaa2me(date1)
+    year2, month2, day2, doy2,modjul2 = noaa2me(date2)
+    deltad = int(modjul2-modjul1)
+    if deltad < 1:
+        print('second time is later than first time OR time is less than one day.')
+        sys.exit()
+
+    metadata = True
+    if (deltad) > 31:
+        tt,obstimes,slevel = multimonthdownload(station,datum,fout,year1,year2,month1,month2,csv)
+        noaa_name = station # this is not hte right one ... but 
+    else:
+        tt = []; slevel = []; obstimes = []
+        # 'data' are stored in the dictionary data
+        data,error = pickup_from_noaa(station,date1,date2,datum,True)
+        if not error:
+            noaa_name = data['metadata']['name']
+            print('WARNING: I have changed the format for this file.')
+            tt,obstimes,slevel = write_out_data(data,fout, tt,obstimes,slevel,csv)
+
+    fout.close()
+    if plt:
+        g.quickp(station,obstimes,slevel)
+
 def noaa_command(station,fout,year,month1,month2,datum,metadata,tt,obstimes,slevel,csv):
     """
     downloads/writes NOAA tidegauge data for one month
@@ -181,6 +309,7 @@ def noaa2me(date1):
 def write_out_data(data,fout, tt,obstimes,slevel,csv):
     """
     writes out the NOAA water level data to a file 
+    20213-mar-27 using new format
 
     Parameters
     ----------
@@ -236,9 +365,13 @@ def write_out_data(data,fout, tt,obstimes,slevel,csv):
 
             slevel.append(sl)
             if csv:
-                fout.write(" {0:4.0f},{1:2.0f},{2:2.0f},{3:2.0f},{4:2.0f},{5:7.3f},{6:3.0f},{7:15.6f},{8:2.0f} \n".format(year, mm, dd, hh, minutes, sl, doy, mjd,ss))
+                fout.write(" {0:4.0f},{1:2.0f},{2:2.0f},{3:2.0f},{4:2.0f},{5:2.0f},{6:7.3f},{7:3.0f},{8:15.6f} \n".format(year, mm, dd, hh, minutes, ss, sl, doy, mjd))
             else:
-                fout.write(" {0:4.0f} {1:2.0f} {2:2.0f} {3:2.0f} {4:2.0f} {5:7.3f} {6:3.0f} {7:15.6f} {8:2.0f} \n".format(year, mm, dd, hh, minutes, sl, doy, mjd,ss))
+                fout.write(" {0:4.0f} {1:2.0f} {2:2.0f} {3:2.0f} {4:2.0f} {5:2.0f} {6:7.3f} {7:3.0f} {8:15.6f} \n".format(year, mm, dd, hh, minutes, ss, sl, doy, mjd))
+            #if csv:
+            #    fout.write(" {0:4.0f},{1:2.0f},{2:2.0f},{3:2.0f},{4:2.0f},{5:7.3f},{6:3.0f},{7:15.6f},{8:2.0f} \n".format(year, mm, dd, hh, minutes, sl, doy, mjd,ss))
+            #else:
+            #    fout.write(" {0:4.0f} {1:2.0f} {2:2.0f} {3:2.0f} {4:2.0f} {5:7.3f} {6:3.0f} {7:15.6f} {8:2.0f} \n".format(year, mm, dd, hh, minutes, sl, doy, mjd,ss))
 
     return tt,obstimes,slevel
 
@@ -288,162 +421,6 @@ def pickup_from_noaa(station,date1,date2,datum, printmeta):
 
     return data, error
 
-def quickp(station,t,sealevel,noaa_name):
-    """
-    makes a quick plot to the screen of the NOAA tide gauge data
-
-    Parameters
-    ----------
-    station : str
-        NOAA station name
-
-    t : datetime
-        times of the water level measurements
-
-    sealevel : numpy array of floats
-        water level in meters
-
-    noaa_name : str
-        long name of the NOAA tide gauge site 
-
-    """
-    fs = 10
-    fig,ax=plt.subplots()
-    ax.plot(t, sealevel, '-')
-    plt.title('Water Levels at ' + noaa_name + ':' + station)
-    plt.xticks(rotation =45,fontsize=fs);
-    plt.ylabel('meters')
-    plt.grid()
-    fig.autofmt_xdate()
-
-    plt.show()
-    return
-
-
-def parse_arguments():
-    parser = argparse.ArgumentParser()
-    parser.add_argument("station", help="station name, e.g. 8768094", type=str)
-    parser.add_argument("date1", help="start-date, 20150101", type=str)
-    parser.add_argument("date2", help="end-date, 20150110", type=str)
-    parser.add_argument("-output", default=None, help="Optional output filename", type=str)
-    parser.add_argument("-plt", default=None, help="quick plot to screen", type=str)
-    parser.add_argument("-datum", default=None, help="datum (lwd for lakes?)", type=str)
-    parser.add_argument("-subdir", default=None, help="optional subdirectory name for output", type=str)
-    args = parser.parse_args().__dict__
-
-    # convert all expected boolean inputs from strings to booleans
-    boolean_args = ['plt']
-    args = str2bool(args, boolean_args)
-
-
-    # only return a dictionary of arguments that were added from the user - all other defaults will be set in code below
-    return {key: value for key, value in args.items() if value is not None}
-
-
-def download_tides(station: str, date1: str, date2: str, output: str = None, plt: bool = False, datum: str = 'mllw', subdir: str = None):
-    """
-    Downloads NOAA tide gauge files and stores locally
-    If you ask for 31 days of data or less, it will download exactly what you ask for.
-    But if you want a longer time series, this code needs to query the NOAA API every month.
-    To make the code easier to write, I start with the first day of the first month you ask for and end with
-    last day in the last month.
-
-    Output is written to REFL_CODE/Files/ unless subdir optional input is set
-    Plot is sent to the screen if requested.
-
-    Parameters 
-    ----------
-    station : str
-        7 character ID of the station.
-
-    date1 : str
-        start date.
-        Example value: 20150101
-
-    date2 : str
-        end date.
-        Example value: 20150110
-
-    output : string, optional
-        Optional output filename
-        default is None
-
-    plt: boolean, optional
-        plot comes to the screen
-        default is None
-
-    datum: string, optional
-        set to lwd for lakes?
-        default is mllw
-
-    subdir : str, optional
-        subdirectory for output in the $REFL_CODE/Files area
-
-    """
-    g.check_environ_variables()
-
-    xdir = os.environ['REFL_CODE']
-    outdir = xdir  + '/Files/'
-    if not os.path.exists(outdir) :
-        subprocess.call(['mkdir', outdir])
-
-    if (subdir is None):
-        print('Using regular output directory',outdir )
-    else:
-        outdir = xdir  + '/Files/' + subdir + '/'
-        print('User requested a subdirectory for output', outdir)
-        if not os.path.exists(outdir):
-            subprocess.call(['mkdir', outdir])
-
-    if len(station) != 7:
-        print('station must have 7 characters ', station); sys.exit()
-    if len(date1) != 8:
-        print('date1 must have 8 characters', date1); sys.exit()
-    if len(date2) != 8:
-        print('date2 must have 8 characters', date2); sys.exit()
-
-
-    csv = False
-    # use the default, which is plain text
-    if output is None:
-        outfile = outdir + station + '_' + 'noaa.txt'
-    else:
-        if output[-3:] == 'csv':
-            csv = True
-        outfile = outdir + output
-
-    print('Writing contents to: ', outfile)
-    fout = open(outfile, 'w+')
-    if csv:
-        fout.write("#YYYY,MM,DD,HH,MM, Water(m),DOY,   MJD, Seconds\n")
-    else:
-        fout.write("%YYYY MM DD HH MM  Water(m) DOY    MJD      Seconds\n")
-        fout.write("% 1    2  3  4  5    6       7       8         9\n")
-
-
-    year1, month1, day1, doy1,modjul1 = noaa2me(date1)
-    year2, month2, day2, doy2,modjul2 = noaa2me(date2)
-    deltad = int(modjul2-modjul1)
-    if deltad < 1:
-        print('second time is later than first time OR time is less than one day.')
-        sys.exit()
-
-    metadata = True
-    if (deltad) > 31:
-        tt,obstimes,slevel = multimonthdownload(station,datum,fout,year1,year2,month1,month2,csv)
-        noaa_name = station # this is not hte right one ... but 
-    else:
-        tt = []; slevel = []; obstimes = []
-        # 'data' are stored in the dictionary data
-        data,error = pickup_from_noaa(station,date1,date2,datum,True)
-        if not error:
-            noaa_name = data['metadata']['name']
-            tt,obstimes,slevel = write_out_data(data,fout, tt,obstimes,slevel,csv)
-
-    fout.close()
-    if plt:
-        quickp(station,obstimes,slevel,noaa_name)
-
 def main():
     args = parse_arguments()
     download_tides(**args)
