@@ -136,26 +136,32 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
                 satlist = onesat_freq_check(onesat,f )
 
             for satNu in satlist:
-                #if screenstats: print('Satellite', satNu)
+                if screenstats: 
+                    print('Satellite', satNu)
                 for a in range(naz):
                     az1 = azval[(a*2)] ; az2 = azval[(a*2 + 1)]
-                    x,y,Nv,cf,UTCtime,avgAzim,avgEdot,Edot2,delT= g.window_data(s1,s2,s5,s6,s7,s8,sat,ele,azi,t,edot,f,az1,az2,e1,e2,satNu,lsp['polyV'],lsp['pele'],screenstats) 
+                    x,y,Nv,cf,UTCtime,avgAzim,avgEdot,Edot2,delT= g.window_data(s1,s2,s5,s6,
+                            s7,s8,sat,ele,azi,t,edot,f,az1,az2,e1,e2,satNu,lsp['polyV'],lsp['pele'],screenstats) 
                     MJD = g.getMJD(year,month,day, UTCtime)
                     if Nv > minNumPts:
                         found_results = True
                         #print('length of x', len(x))
                         maxF, maxAmp, eminObs, emaxObs,riseSet,px,pz= g.strip_compute(x,y,cf,maxH,lsp['desiredP'],lsp['polyV'],minH) 
-                        nij =   pz[(px > NReg[0]) & (px < NReg[1])]
-                        Noise = 0
-                        if (len(nij) > 0):
-                            Noise = np.mean(nij)
-                        iAzim = int(avgAzim)
-                        tooclose = False
-                        if abs(maxF - minH) < 0.10: #  peak too close to min value
-                            tooclose = True
+                        if (maxF ==0) & (maxAmp == 0):
+                            #print('you have tripped a warning')
+                            tooclose == True; Noise = 1; iAzim = 0;
+                        else:
+                            nij =   pz[(px > NReg[0]) & (px < NReg[1])]
+                            Noise = 1
+                            if (len(nij) > 0):
+                                Noise = np.mean(nij)
+                            iAzim = int(avgAzim)
+                            tooclose = False
+                            if abs(maxF - minH) < 0.10: #  peak too close to min value
+                                tooclose = True
                         # KL added 2022 march 26
-                        if abs(maxF - maxH) < 0.10: #  peak too close to max value
-                            tooclose = True
+                            if abs(maxF - maxH) < 0.10: #  peak too close to max value
+                                tooclose = True
                         if (not tooclose) & (delT < lsp['delTmax']) & (eminObs < (e1 + ediff)) & (emaxObs > (e2 - ediff)) & (maxAmp > reqAmp[ct]) & (maxAmp/Noise > PkNoise):
                             # request from a tide gauge person for Month, Day, Hour, Minute
                             if lsp['mmdd']:
@@ -165,6 +171,7 @@ def gnssir_guts(station,year,doy, snr_type, extension,lsp):
                                 fout.write(" {0:4.0f} {1:3.0f} {2:6.3f} {3:3.0f} {4:6.3f} {5:6.2f} {6:6.2f} {7:6.2f} {8:6.2f} {9:4.0f} {10:3.0f} {11:2.0f} {12:8.5f} {13:6.2f} {14:7.2f} {15:12.6f} {16:1.0f} \n".format(year,doy,maxF,satNu, UTCtime, avgAzim,maxAmp,eminObs,emaxObs,Nv, f,riseSet, Edot2, maxAmp/Noise, delT, MJD,irefr)) 
                             gj +=1
                             if screenstats:
+                                print('Writing out ', np.round(Edot2,3), np.round(avgEdot,3))
                                 T = g.nicerTime(UTCtime)
                                 print('SUCCESS Azimuth {0:3.0f} Sat {1:3.0f} RH {2:7.3f} m PkNoise {3:4.1f} Amp {4:4.1f} Fr{5:3.0f} UTC {6:5s} DT {7:3.0f} '.format(iAzim,satNu,maxF,maxAmp/Noise,maxAmp, f,T,round(delT)))
                             if plot_screen:
