@@ -4,15 +4,17 @@
 # this should replace the spaghetti code in gps.py
 import datetime
 import json
+import numpy as np
 import os
 import requests
 import sys
 import subprocess
+import time
 import wget
 from urllib.parse import urlparse
 # local libraries
 import gnssrefl.gps as g
-import gnssrefl.cddis_highrate as ch
+import gnssrefl.highrate as ch
 import gnssrefl.kelly as kelly
 
 def gogetit(dir1, filename, ext):
@@ -167,7 +169,17 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
             print('File was not found: at bfg.')
 
         return file_name,foundit
-
+    cydoy =  cyyyy + '/' + cdoy + '/'
+    s1 = time.time()
+    if (archive == 'unavco'):
+        # original dir1 = 'https://data.unavco.org/archive/gnss/rinex3/obs/' + cyyyy + '/' + cdoy + '/'
+        #url1 =      'https://data-idm.unavco.org/archive/gnss/rinex3/obs/' + cydoy + file_name
+        url1 =      'https://data.unavco.org/archive/gnss/rinex3/obs/' + cydoy + file_name
+        print('Testing new unavco protocols:',url1)
+        foundit,file_name = kelly.the_kelly_simple_way(url1,file_name)
+        s2 = time.time()
+        print('Download took ',np.round(s2-s1,2), ' seconds') 
+        return file_name,foundit
 
     try:
         if (archive == 'ign'):
@@ -199,12 +211,13 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
         elif (archive == 'nrcan'):
             dir1 = 'https://cacsa.nrcan.gc.ca/gps/data/gpsdata/' + cyy + cdoy  + '/' + cyy + 'd' + '/'
             wget.download(dir1+file_name,file_name)
-        elif (archive == 'unavco'):
+        elif (archive == 'unavco-old'):
             dir1 = 'https://data.unavco.org/archive/gnss/rinex3/obs/' + cyyyy + '/' + cdoy + '/'
             wget.download(dir1+file_name,file_name)
         elif (archive == 'gfz'):
             # no idea
-            dir1 = 'ftp://isdcftp.gfz-potsdam.de/gnss/data/daily/' + cyyyy + '/' + cdoy
+            dir1 = 'ftp://isdcftp.gfz-potsdam.de/gnss/data/daily/' + cyyyy + '/' + cdoy + '/'
+            print(dir1+file_name)
             wget.download(dir1+file_name,file_name)
         elif (archive == 'cddis'):
             new_way_dir = '/gnss/data/daily/' + cyyyy + '/' + cdoy + '/' + cyy + 'd/'
@@ -214,7 +227,8 @@ def universal(station9ch, year, doy, archive,srate,stream,debug=False):
             return '', ''
     except:
         okokok = 1
-
+    s2 = time.time()
+    print('Download took ',np.round(s2-s1,2), ' seconds') 
     if os.path.exists(file_name):
         siz = os.path.getsize(file_name)
         if (siz == 0):
@@ -321,16 +335,12 @@ def universal_all(station9ch, year, doy, srate,stream):
     ----------
     station9ch : str
         9 character station name
-
     year : int
         full year
-
     doy : int
         doy of year
-
     srate : int
         receiver sample rate 
-
     stream : str
         R or S
 
@@ -338,7 +348,6 @@ def universal_all(station9ch, year, doy, srate,stream):
     -------
     file_name : str
         rinex filename
-
     foundit : bool
         whether rinex file was found
 
@@ -430,24 +439,26 @@ def universal_rinex2(station, year, doy, archive):
     cydoy = cyyyy + '/' + cdoy + '/'
     cyy = cyyyy[2:4]
 
+    s1 = time.time()
     if (archive == 'jp'):
         # i did not want to rewrite the code
         gsi_data(station, year, doy)
         file_name = oname
         if os.path.exists(file_name):
             foundit = True
-    elif (archive == 'unavco'):
+    elif (archive == 'unavco-old'):
         dir1 = 'https://data.unavco.org/archive/gnss/rinex/obs/' + cydoy
         foundit, file_name = gogetit(dir1, dname, '.Z'); 
         if not foundit:
             foundit, file_name = gogetit(dir1, oname, '.Z')
-    elif (archive == 'unavco2'):
+    elif (archive == 'unavco'):
         print('testing out new protocol at unavco')
-        url1 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
-        foundit,file_name = kelly.the_kelly_simple_way(url1,dname + '.Z')
+        #url1 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
+        url1 = 'https://data.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
+        foundit,file_name = kelly.the_kelly_simple_way(url1, dname + '.Z')
         if not foundit:
-            url2 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + oname + '.Z'
-            foundit,file_name = kelly.the_kelly_way(url2,oname + '.Z')
+            url2 = 'https://data.unavco.org/archive/gnss/rinex/obs/' + cydoy + oname + '.Z'
+            foundit,file_name = kelly.the_kelly_simple_way(url2, oname + '.Z')
 
     elif (archive == 'special'):
         dir1 = 'https://data.unavco.org/archive/gnss/products/reflectometry/' + cydoy
@@ -509,6 +520,9 @@ def universal_rinex2(station, year, doy, archive):
     else:
          print('I do not recognize your archive')
 
+    s2 = time.time()
+    print('Download took ', np.round(s2-s1,2),' seconds') 
+
     if not os.path.exists(file_name):
         print('Did not find the Rinex file')
     return file_name,foundit
