@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-converts latlonht to cartesian coordinates
+
 """
 import argparse
 import sys
@@ -8,6 +8,24 @@ import sys
 import gnssrefl.gps as g
 
 def main():
+    """
+    Command line tool that converts latitude, longitude, and 
+    ellipsoidal ht to Cartesian coordinates  and prints to the screen
+
+    Parameters
+    ----------
+    lat : float
+        latitude in degrees
+    lon : float
+        longitude in degrees
+    height : float
+        ellipsoidal height in meters
+
+    Returns
+    -------
+    XYZ : float
+        Cartesian coordinates to the screen (m)
+    """
 
     parser = argparse.ArgumentParser()
     parser.add_argument("lat", help="latitude (deg) ", type=float)
