@@ -8,17 +8,18 @@ import gnssrefl.gps as g
 
 def main():
     """
-    query_unr: extracts coordinates for stations that were in UNR database.
-    in late 2021.  
+    Extracts coordinates for stations that were in the UNR database 
+    in late 2021. Prints both geodetic and cartesian values.
 
     Parameters
     ----------
     station : str
         four character station name
+
     """
 
     parser = argparse.ArgumentParser()
-    parser.add_argument("station", help="4 ch station name (lowercase)", type=str)
+    parser.add_argument("station", help="4-ch station name (lowercase)", type=str)
 
     args = parser.parse_args()
 
@@ -26,7 +27,7 @@ def main():
     if len(station) != 4:
         print('illegal station name-must be 4 characters')
         sys.exit()
-    alat,alon,ht=g.queryUNR_modern(station)
+    alat,alon,ht=g.queryUNR_modern(station.lower())
     if (alat+alon+ht) != 0:
         x,y,z=g.llh2xyz(alat,alon,ht)
         print('XYZ', round(x,4),round(y,4),round(z,4) )
