@@ -18,7 +18,7 @@ from progress.bar import Bar
 import gnssrefl.gps as g
 import gnssrefl.rinpy as rinpy
 import gnssrefl.karnak_libraries as k
-import gnssrefl.cddis_highrate as ch
+import gnssrefl.highrate as ch
 
 # fortran codes for translating RINEX
 import gnssrefl.gpssnr as gpssnr
@@ -62,7 +62,7 @@ def quickname(station,year,cyy, cdoy, csnr):
     return fname
 
 def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate,
-        mk,skipit,stream,strip):
+        mk,skipit,stream,strip,bkg):
     """
     main code to convert RINEX files into SNR files that are stored locally
 
@@ -74,13 +74,14 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     year_list : list of int
         years to be analyzed
 
-    doy_list list of doy to be analyzed
+    doy_list : list of integers
+        doys to be analyzed
 
     isnr : integer
         SNR file type choice
 
     orbtype : string
-        3 character orbit type, e.g. nav
+        orbit type, e.g. nav, rapid, gnss
 
     rate : string
         general sample rate.
@@ -122,11 +123,14 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
          reduces observables to only SNR (too many observables, particularly in RINEX 2 files
          will break the RINEX translator)
 
+    bkg : str
+         location of bkg files, EUREF or IGS
+
     """
     #
     if archive == 'special':
-        print('The special option needs to be updated for new UNAVCO/Earthscope protocols. Please contact')
-        print('Tim Dittmann or Kelly Enloe at Earthscope if your file download does not work.')
+        print('The special option needs to be updated for new UNAVCO/Earthscope protocols. Please submit ')
+        print('an issue at https://github.com/kristinemlarson/gnssrefl.')
     # do not allow illegal skipit values
     if skipit < 1:
         skipit = 1
@@ -264,7 +268,7 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                                     print('The RINEX 3 file has been downloaded. Try to make ', r2)
                                     fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
                             if archive == 'bkg':
-                                rnx_filename,foundit = ch.bkg_highrate(station9ch, year, doy, 0,stream,dec_rate)
+                                rnx_filename,foundit = ch.bkg_highrate(station9ch, year, doy, 0,stream,dec_rate,bkg)
                                 if foundit:
                                     print('The RINEX 3 file has been downloaded and merged. Try to make ', r2)
                                     fexists = g.new_rinex3_rinex2(rnx_filename,r2,dec_rate)
@@ -369,7 +373,8 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
                 # added karnak librariies
                 if (archive == 'all'):
                     foundrinex = False
-                    for archivechoice in ['unavco','sopac','sonel']:
+                    # sopac put before unavco
+                    for archivechoice in ['sopac','unavco','sonel']:
                         if (not foundrinex):
                             file_name,foundrinex = k.universal_rinex2(station, year, doy, archivechoice)
                 else:
