@@ -49,7 +49,8 @@ def writeout_spline_outliers(tvd_bad,txtdir,residual,filename):
             fy = tvd_bad[w,1] + tvd_bad[w,4]/24 # fractional day of year
             deltaT = tvd_bad[w,14]
             mjd = tvd_bad[w,15]
-            fout.write('{0:3.0f} {1:7.2f} {2:7.2f} {3:7.2f} {4:9.3f} {5:15.7f} \n'.format( tvd_bad[w,3], tvd_bad[w,5], deltaT,residual[w],fy,mjd ))
+            fout.write('{0:3.0f} {1:7.2f} {2:7.2f} {3:7.2f} {4:9.3f} {5:15.7f} {6:7.2f} \n'.format( 
+                tvd_bad[w,3], tvd_bad[w,5], deltaT,residual[w],fy,mjd,tvd_bad[w,2] ))
         fout.close()
 
     return
@@ -271,7 +272,8 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
     fout.close()
 
 
-def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim1,azim2,ampl,peak2noise,txtfile,h1,h2,kplt,txtdir,default_usage):
+def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim1,azim2,ampl,
+        peak2noise,txtfile,h1,h2,kplt,txtdir,default_usage):
     """
     reads in RH results and makes various plots to help users assess the quality of the solution
 
@@ -365,7 +367,7 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
                             print('some issue with ',fname)
 
     else:
-        # using external file of concatenated results
+        print('using external file of concatenated results', txtfile)
         tv = np.loadtxt(txtfile,comments='%')
 
      
@@ -442,7 +444,7 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
             rh_plots(otimes,tv,station,txtdir,year,d1,d2,True)
             rh_plots(otimes,tv,station,txtdir,year,d1,d2,False)
 
-        plt.show()
+        #plt.show()
 
 
     # now write things out - using txtdir variable sent 
@@ -746,11 +748,11 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     colorbar.set_label('Frequency', fontsize=fs)
     ax1.set_title('Signals',fontsize=fs)
     plt.xticks(rotation =45,fontsize=fs); 
-    ax1.set_ylabel('meters',fontsize=fs)
+    ax1.set_ylabel('RH (m)',fontsize=fs)
     plt.yticks(fontsize=fs)
     ax1.invert_yaxis()
     ax1.grid(True)
-    fig.suptitle( station.upper() + ' Reflector Heights', fontsize=fs)
+    #fig.suptitle( station.upper() + ' Reflector Heights', fontsize=fs)
     if setlimits:
         ax1.set_xlim((th1, th2))
     fig.autofmt_xdate()
@@ -763,7 +765,7 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     scatter = ax2.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
     colorbar = fig.colorbar(scatter, ax=ax2)
     colorbar.set_label('deg', fontsize=fs)
-    ax2.set_ylabel('meters',fontsize=fs)
+    ax2.set_ylabel('RH (m)',fontsize=fs)
     ax2.set_title('Azimuth',fontsize=fs)
     #ax1.title.set_text('Azimuth')
     plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
@@ -779,7 +781,7 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
     scatter = ax3.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
     colorbar = fig.colorbar(scatter, ax=ax3)
-    ax3.set_ylabel('meters',fontsize=fs)
+    ax3.set_ylabel('RH (m)',fontsize=fs)
     colorbar.set_label('v/v', fontsize=fs)
     plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
     ax3.set_title('Amplitude',fontsize=fs)
@@ -836,7 +838,8 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     plt.savefig(plotname,dpi=150)
     print('png file saved as: ', plotname)
 
-    fig = plt.figure()
+    #    fig=plt.figure(figsize=(10,6))
+    fig = plt.figure(figsize=(10,6))
     colors = tv[:,5]
 # put some amplitude information on it
 # ax.plot( otimes, tv[:,2], '.')
@@ -852,7 +855,7 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     plt.plot(otimesarray[ii],tv[ii,2], 'r.',markersize=4,label='outliers')
     #plt.plot(otimesarray[ii],tv[ii,2], '.',color='red',label='outliers',markersize=12)
     plt.legend(loc="best",bbox_to_anchor=(0.95, 0.9),prop={"size":8})
-    plt.title(station.upper() + ' Reflector Heights', fontsize=8)
+    plt.title('Raw ' + station.upper() + ' Reflector Heights', fontsize=8)
     plt.ylabel('meters',fontsize=8)
     plt.gca().invert_yaxis()
     plt.xticks(rotation =45,fontsize=8); plt.yticks(fontsize=8)
@@ -866,7 +869,7 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     plt.gca().invert_yaxis()
     plt.ylabel('meters',fontsize=8)
     plt.xticks(rotation =45,fontsize=8); plt.yticks(fontsize=8)
-    plt.title('Edited Reflector Heights', fontsize=8)
+    plt.title('Edited ' + station.upper() + ' Reflector Heights', fontsize=8)
     plt.grid() ; fig.autofmt_xdate()
     plotname = txtdir + '/' + station + '_outliers.png'
     plt.savefig(plotname,dpi=300)
@@ -1127,7 +1130,7 @@ def flipit(tvd,col):
     return tnew, ynew
 
 
-def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
+def rhdot_correction2(station,fname,fname_new,pltit,outlierV,outlierV2,**kwargs):
     """
     Improved code to compute rhdot correction and bias correction for subdaily
 
@@ -1146,11 +1149,13 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
         whether you want plots to the screen
 
     outlierV : float
-       outlier criterion, in meters 
+       outlier criterion, in meters  used in first go thru
+       if None, then use 3 sigma (which is the default)
+    outlierV2 : float
+       outlier criterion, in meters  used in second go thru
+       if None, then use 3 sigma (which is the default)
 
     """
-    # this is not being used 
-    outlierV = float(outlierV) #just to make sure - i think it was sending a string
     # output will go to REFL_CODE/Files unless txtdir provided
     xdir = os.environ['REFL_CODE']
 
@@ -1160,6 +1165,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     else:
         txtdir = val
 
+
     delta_out = kwargs.get('delta_out',0)
     if (delta_out  == 0):
         splineout = False
@@ -1181,10 +1187,18 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     # knots_per_day = 8
     knots_default = 8
     knots_per_day= kwargs.get('knots',8)
-    print('\n>>>>>>>>>>>>>>>>>>>> Entering spline fit <<<<<<<<<<<<<<<<<<<<<<<<')
-    print('Improved code to compute rhdot correction and bias correction for subdaily')
+
+
+    knots_test = kwargs.get('knots_test',0)
+    if (knots_test== 0):
+        knots_test = knots_per_day
+    else:
+        print('using knots_test')
+
+    print('\n>>>>>>>>>>>>>>>>>>>> Entering second section of subdaily code <<<<<<<<<<<<<<<<<<<<<<<<')
+    print('\nComputes rhdot correction and bias correction for subdaily')
     print('\nInput filename:', fname)
-    print('Output filename: ', fname_new)
+    print('\nOutput filename: ', fname_new)
 
     # read in the lomb scargle values which are the output of gnssir
     # i.e. the reflector heights
@@ -1223,8 +1237,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     print('Average num of RH obs per day', '{0:5.1f} '.format (len(h)/Ndays) )
     print('Knots per day: ', knots_per_day, ' Number of knots: ', numKnots)
     # currently using 3 sigma
-    #print('Outlier criterion with respect to spline fit (m): ', outlierV)
-    # 
+    print('Outlier criterion for the first splinefit (m):', outlierV)
+    print('Outlier criterion for the second splinefit (m):', outlierV2)
 
     firstKnot_in_minutes = 15
     t1 = tnew.min()+firstKnot_in_minutes/60/24
@@ -1291,16 +1305,27 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     plt.subplot(2,1,2)
     plt.plot(th, residual_after,'r.',label='all pts')
 
+    if outlierV is None:
+    # use 3 sigma
+        OutlierLimit = 3*sigmaAfter
+        print('Using three sigma outlier criteria')
+    else:
+        OutlierLimit = float(outlierV)
+        print('User-defined splinefit outlier value (m): ', OutlierLimit)
 
-    tvd_bad = tvd[np.abs(residual_after) >  3*sigmaAfter, :]
+    tvd_bad = tvd[np.abs(residual_after) >  OutlierLimit, :]
+    #tvd_bad = tvd[np.abs(residual_after) >  3*sigmaAfter, :]
 
 
-    kk = np.abs(residual_after) > 3*sigmaAfter
+    #kk = np.abs(residual_after) > 3*sigmaAfter
+    kk = np.abs(residual_after) > OutlierLimit
     tvd_confused = tvd[kk,:]
+
     writeout_spline_outliers(tvd_confused,txtdir,residual_after[kk],'outliers.spline.txt')
 
     # keep values within 3 sigma 
-    ii = np.abs(residual_after) < 3*sigmaAfter
+    #ii = np.abs(residual_after) < 3*sigmaAfter
+    ii = np.abs(residual_after) <= OutlierLimit
     tvd_new = tvd[ii,:]
     correction_new = correction[ii]
     correctedRH_new = correctedRH[ii]
@@ -1371,8 +1396,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     if not apply_if_corr:
         print('You chose not to correct for IF biases. Exiting')
-        if pltit:
-            plt.show()
+        #if pltit:
+        #    plt.show()
         return tvd_new, correction
 
     # now try to write the bias corrected values
@@ -1391,6 +1416,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     tnew, ynew = flipit(tvd_new,column)
 
     Ndays = tnew.max()-tnew.min()
+    knots_per_day = knots_test
+    print('trying knots_test')
     numKnots = int(knots_per_day*(Ndays))
     #
 
@@ -1414,38 +1441,52 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     newsigma = np.std(biasCor_rh-spline_at_GPS)
     strsig = str(round(newsigma,3)) + '(m)'
 
-    fig=plt.figure(figsize=(10,6))
-    plt.subplot(2,1,1)
+    fig=plt.figure(figsize=(10,5))
+    #plt.subplot(2,1,1)
     plt.plot(th, biasCor_rh, 'b.', label='RH with RHdot/IFcorr ' + strsig)
     plt.plot(th_even, spline_whole_time, 'c-',label='newspline')
 
-    # identify 3 sigma outliers
-    ii = np.abs(biasCor_rh -spline_at_GPS)/newsigma > 3
-    # points to keep
-    jj = np.abs(biasCor_rh -spline_at_GPS)/newsigma < 3
+    if outlierV2 is None:
+        # use 3 sigma to find outliers
+        OutlierLimit = 3*sigmaAfter
+        print('Using three sigma outlier criteria')
+        ii = np.abs(biasCor_rh -spline_at_GPS)/newsigma > 3
+        jj = np.abs(biasCor_rh -spline_at_GPS)/newsigma <= 3
+    else:
+        OutlierLimit = float(outlierV2)
+        print('User-defined splinefit outlier value (m): ', OutlierLimit)
+        # throw out
+        ii = np.abs(biasCor_rh -spline_at_GPS) > OutlierLimit
+        # points to keep
+        jj = np.abs(biasCor_rh -spline_at_GPS) <= OutlierLimit
 
-    plt.plot(th[ii], biasCor_rh[ii], 'rx', label='3-sig outliers')
+
+    plt.plot(th[ii], biasCor_rh[ii], 'rx', label='outliers')
 
     plt.legend(loc="upper left")
     plt.grid()
     plt.gca().invert_yaxis()
     plt.ylabel('meters')
-    plt.title('New spline with RHdot corr/InterFreq corr/initial 3sigma outliers removed')
+    plt.title('Station: ' + station + ', new spline, RHdot corr/InterFreq corr/outliers removed')
+    plt.xlabel('days of the year')
+    g.save_plot(txtdir + '/' + station + '_rhdot4.png')
 
-    plt.subplot(2,1,2)
+    fig=plt.figure(figsize=(10,5))
+    #plt.subplot(2,1,1)
     plt.plot(th, biasCor_rh - spline_at_GPS, 'b.',label='all residuals')
-    plt.title('Residuals to new spline fit')
+    plt.title('Station:' + station + ' Residuals to new spline fit')
     plt.grid()
     plt.ylabel('meters')
     plt.xlabel('days of the year')
 
-    plt.plot(th[ii], (biasCor_rh -spline_at_GPS)[ii], 'r.',label='3-sig')
+    plt.plot(th[ii], (biasCor_rh -spline_at_GPS)[ii], 'r.',label='outliers')
     # will write these residauls out to a file
     badpoints2 =  (biasCor_rh -spline_at_GPS)[ii]
     plt.legend(loc="upper left")
 
-    print('RMS with frequency bias taken out (m) ', np.round(newsigma,3)  )
-    g.save_plot(txtdir + '/' + station + '_rhdot4.png')
+    print('RMS with frequency biases and RHdot taken out (m) ', np.round(newsigma,3)  )
+    g.save_plot(txtdir + '/' + station + '_rhdot5.png')
+    plt.close() # dont send this one to the screen
 
     # bias corrected - and again without 3 sigma outliers
     bias_corrected_filename = fname_new + 'IF'; extraline = ''; writecsv = False
@@ -1480,7 +1521,9 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
             splinefileout =  txtdir + '/' + station + '_' + str(iyear) + '_spline_out.txt'
             print('Writing evenly sampled file to: ', splinefileout)
             fout = open(splinefileout,'w+')
-            fout.write('{0:1s}  {1:30s}  \n'.format('%','This is a spline fit - be careful when interpreting'))
+            fout.write('{0:1s}  {1:30s}  \n'.format('%','This is NOT observational data - be careful when interpreting it.'))
+            fout.write('{0:1s}  {1:30s}  \n'.format('%','If the data are not well represented by the spline functions, you will '))
+            fout.write('{0:1s}  {1:30s}  \n'.format('%','have a very poor representation of the data. '))
             fout.write('{0:1s}  {1:30s}  \n'.format('%','MJD, RH(m), YY,MM,DD,HH,MM,SS'))
             dtime = False
             for i in range(0,N):
@@ -1501,8 +1544,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
         plt.xlabel('delta Time (minutes)')
 
 
-    if pltit:
-        plt.show()
+    #if pltit:
+    #    plt.show()
 
     return tvd, correction
 
@@ -1566,9 +1609,12 @@ def rh_plots(otimes,tv,station,txtdir,year,d1,d2,percent99):
 
     # now doing 1 and 99%
     p1 = 0.01; p2 = 0.99
-    lowv, highv = my_percentile(tv[:,2],p1, p2)
+    #lowv, highv = my_percentile(tv[:,2],p1, p2)
     # this crashed my docker build - but it turned out to have nothing to do with it
-#    yl = np.percentile(tv[:,2] ,[1 ,99])
+    yl = np.percentile(tv[:,2] ,[1 ,99])
+    print('percentile values',yl)
+    lowv = yl[0]; highv = y[1]
+    
     if percent99:
         ax2.set_ylim((lowv,highv))
 
